summaryrefslogtreecommitdiffstats
path: root/formats
diff options
context:
space:
mode:
authorJan Pokorný <jpokorny@redhat.com>2015-03-25 10:48:55 +0100
committerJan Pokorný <jpokorny@redhat.com>2015-04-08 19:55:31 +0200
commit7f3f4fc587c279820b3d9994cfc5c6197b95bbd1 (patch)
treeb762ce6589efe2c930ed2e84616957210221d7dc /formats
parente6781bbac004c4e8fa9fc805b02108f22fddd9e9 (diff)
downloadclufter-7f3f4fc587c279820b3d9994cfc5c6197b95bbd1.tar.gz
clufter-7f3f4fc587c279820b3d9994cfc5c6197b95bbd1.tar.xz
clufter-7f3f4fc587c279820b3d9994cfc5c6197b95bbd1.zip
refactor: pcs (not in command names) -> cib
"pcs" should be reserved for actual pcs CLI tool commands. Signed-off-by: Jan Pokorný <jpokorny@redhat.com>
Diffstat (limited to 'formats')
-rw-r--r--formats/cib.py (renamed from formats/pcs.py)20
1 files changed, 10 insertions, 10 deletions
diff --git a/formats/pcs.py b/formats/cib.py
index 2c93d7b..574ae85 100644
--- a/formats/pcs.py
+++ b/formats/cib.py
@@ -1,17 +1,17 @@
# -*- coding: UTF-8 -*-
-# Copyright 2014 Red Hat, Inc.
+# Copyright 2015 Red Hat, Inc.
# Part of clufter project
# Licensed under GPLv2+ (a copy included | http://gnu.org/licenses/gpl-2.0.txt)
"""Pacemaker configuration system (pcs) format"""
__author__ = "Jan Pokorný <jpokorny @at@ Red Hat .dot. com>"
from ..format import XML
-class pcs(XML):
+class cib(XML):
"""Pacemaker-based cluster stack configuration (as XML/CIB)
Also known as Pacemaker Configuration System (pcs).
"""
# XML
root = 'cib'
@@ -20,22 +20,22 @@ class pcs(XML):
}
-class pcs_prelude(pcs):
+class cib_prelude(cib):
"""Private, "unfinished" pacemaker-based cluster stack configuration
- This is a result of ccsflat2pcsprelude filter.
+ This is a result of ccsflat2cibprelude filter.
"""
-class pcs_compact(pcs):
+class cib_compact(cib):
"""Private, "unfinished" pacemaker-based cluster stack configuration
- This is a result of pcsprelude2pcscompact filter.
+ This is a result of cibprelude2cibcompact filter.
"""
-class pcs_final(pcs):
+class cib_final(cib):
"""Public, "finished" pacemaker-based cluster stack configuration
- This is a result of pcs2pcsfinal filter.
+ This is a result of cib2cibfinal filter.
"""
@@ -1,17 +1,17 @@
# Part of clufter project
# Licensed under GPLv2+ (a copy included | http://gnu.org/licenses/gpl-2.0.txt)
-"""Pacemaker configuration system (pcs) format"""
+"""Pacemaker configuration system/Cluster Information Base (CIB) format"""
__author__ = "Jan Pokorný <jpokorny @at@ Red Hat .dot. com>"
from ..format import XML
@@ -1,17 +1,17 @@
"""Pacemaker-based cluster stack configuration (as XML/CIB)
- Also known as Pacemaker Configuration System (pcs).
+ Also known as Pacemaker Configuration System (cib).
"""
# XML